@@ -12,7 +12,6 @@ class ModbusConnection:     #Singleton
     __instance__ = None
     __connectionErrorCounter__ = None
     __connectionCounter__ = None
-    __connectionErrorRate__ = None
     __modbusConnection__ = None
     __modbusClient__ = None
     __mutex__ = threading.Lock()
@@ -34,7 +33,6 @@ class ModbusConnection:     #Singleton
 
         self.__connectionErrorCounter__ = dict()
         self.__connectionCounter__ = dict()
-        self.__connectionErrorRate__ = dict()
         self.__modbusClient__ = ModbusClient(method = "rtu", port="/dev/ttyUSB0", stopbits = 1, bytesize = 8, parity = 'N', baudrate= 9600, timeout=0.2, retry_on_empty=True, retry_on_invalid=True)
 
     def __increaseModbusErrorCounter__(self, nodeId):
@@ -54,10 +52,16 @@ class ModbusConnection:     #Singleton
             self.__connectionErrorCounter__[nodeId] = 0
             return 0
 
-    def getModbusErrorRate(self, nodeId):
+    def getModbusErrorRate(self, node):
         try:
-            return self.__connectionErrorRate__[nodeId]
+            self.__connectionErrorCounter__[node]
         except:
+            return 0
+
+        try:
+            return round(self.__connectionErrorCounter__[node] / self.__connectionCounter__[node], 2)
+        except:
+            logging.warning("[ModbusConnection] Node " + str(node) + ": Cannot calculate error rate.")
             return None
 
     def resetCounters(self, nodeId):
@@ -114,11 +118,6 @@ class ModbusConnection:     #Singleton
                 self.__connectionCounter__[node] += 1
             except:
                 self.__connectionCounter__[node] = 1
-
-            try:
-                self.__connectionErrorRate__[node] = round(self.__connectionErrorCounter__[node] / self.__connectionCounter__[node], 2)
-            except:
-                logging.debug("[ModbusConnection] Node " + str(node) + ": Cannot calculate error rate.")
             
             if self.__modbusClient__ != None:
                 if(self.__connectSocket__()):
