@@ -8,6 +8,7 @@ from datetime import datetime
 from colr import color
 import sys
 import os
+import random
 
 PACKAGE_PARENT = '..'
 SCRIPT_DIR = os.path.dirname(os.path.realpath(os.path.join(os.getcwd(), os.path.expanduser(__file__))))
@@ -15,12 +16,12 @@ sys.path.append(os.path.normpath(os.path.join(SCRIPT_DIR, PACKAGE_PARENT)))
 
 from mypvdevices.DcsConnection import DcsConnection
 
-BUILDNR = "1.2102.17"
+BUILDNR = "1.2102.19"
 
 JOINTIMEOUT = 5
 SERIALLEN = 16
 DEVICESLEEPTIME = 10
-DEFAULTMODBUSFREQUENCY = 3
+DEFAULTMODBUSFREQUENCY = 15
 
 class ModbusDevice:
     __firmwareversion__ = "2." + str(BUILDNR)
@@ -193,6 +194,7 @@ class ModbusDevice:
                 if self.__modBusExecuted__ != None:
                     difference = datetime.now() - self.__modBusExecuted__
                     if(difference.total_seconds() > self.__modbusFrequency__ * 3):
+                        logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " modbus data too old: " + str(difference.total_seconds()))
                         if self.__datasets__ != None:
                             for dataset in self.__datasets__:
                                 self.__data__[dataset] = None
@@ -267,11 +269,21 @@ class ModbusDevice:
 
     def __runmodbus__(self):
         while self.__running__:
+            modbusstarttime = datetime.now()
             try:
-                self.__modBusExecuted__ = datetime.now()
+                logging.debug("[ModbusDevice] " + self.getidentifier() + ". Running modbus...")
                 self.__excecutemodbus__()
+                self.__modBusExecuted__ = datetime.now()
             except Exception as e:
                 logging.error("[ModbusDevice] " + self.getidentifier() + ". Modbus Thread Error: " + str(e))
+            
+            executiontime = datetime.now() - modbusstarttime
+            logging.debug("[ModbusDevice] ID " + str(self.__serial__) + " modbus execution time: " + str(executiontime.total_seconds()))
+            if(executiontime.total_seconds() > DEFAULTMODBUSFREQUENCY):
+                logging.warning("[ModbusDevice] ID " + str(self.__serial__) + " modbus execution time too high: " + str(executiontime.total_seconds()))
+
+            time.sleep(random.random())        
+            time.sleep(self.__modbusFrequency__)
 
     def __excecutemodbus__(self):
         if self.__modbusFrequency__ > 0:
@@ -296,7 +308,6 @@ class ModbusDevice:
                     logging.warning("[ModbusDevice] " + self.getidentifier() + ". processing registers not successfull. " + str(e))
             else:
                 logging.debug("[ModbusDevice] " + self.getidentifier() + ". No registers to process.")
-            time.sleep(self.__modbusFrequency__)
 
     def __syncsettings__(self):
         errors = 0
